@@ -1,4 +1,3 @@
-use std::sync::Arc;
 use wgpu::util::{BufferInitDescriptor, DeviceExt};
 use wgpu::{
     BindGroup, BindGroupDescriptor, BindGroupLayout, BindGroupLayoutDescriptor, Buffer,
@@ -164,7 +163,7 @@ pub trait DeviceAsyncExt {
         &'a self,
         queue: &Queue,
         desc: &'a TextureDescriptor<'a>,
-        data: Vec<u8>,
+        data: &'a [u8],
     ) -> Texture;
 }
 
@@ -293,8 +292,8 @@ impl DeviceAsyncExt for Device {
         &'a self,
         queue: &Queue,
         desc: &'a TextureDescriptor<'a>,
-        data: Vec<u8>,
+        data: &'a [u8],
     ) -> Texture {
-        tokio::task::block_in_place(|| self.create_texture_with_data(queue, desc, &data))
+        tokio::task::block_in_place(|| self.create_texture_with_data(queue, desc, data))
     }
 }
